local addonVar = ScreenPlus.getVar() -- ///// copie de la locale addonVar pour ce fichier

local panel
local classicMargin = 15
local availableWidth = 622 - (classicMargin * 2)
if (ScreenPlus.isRetail()) then
	classicMargin = 0
	availableWidth = 665
end

----------------------------------------------------------------------------------------
------------------------------------- CONSTRUCTION -------------------------------------

function ScreenPlus.settingsCreate()
	local margeH = classicMargin + 20
	local subFrame, fontString
	
	local thisAddon, addonTitle, addonNotes = GetAddOnInfo(addonVar["name"])
	local titleString = panel:CreateFontString(addonVar["settingsPanel"].."_Title", "ARTWORK", "GameFontNormalLarge")
	titleString:SetPoint("TOPLEFT", classicMargin + 5, -(classicMargin + 5))
	titleString:SetText(addonTitle.." v"..ScreenPlus.getVersion(false))
	-------------------------- author
	fontString = panel:CreateFontString(addonVar["settingsPanel"].."_Author", "ARTWORK", "GameFontNormalSmall")
	fontString:SetPoint("LEFT", titleString, "RIGHT", 80, -1)
	fontString:SetTextColor(0.5, 0.5, 0.9, 1)
	fontString:SetText("Copyright "..GetAddOnMetadata(ScreenPlus.getVar("name"), "Author"))
	-------------------------- infos/notes
	local infosFrame = ScreenPlus.createTextFrame(nil, panel, availableWidth - (margeH * 2), addonNotes, 0)
	infosFrame:SetPoint("TOPLEFT", titleString, "BOTTOMLEFT", margeH, -5)
	ScreenPlus.setFontStyle(infosFrame.font, nil, 12, "#AAAABB", false, nil)
	------------------------- help
	subFrame = ScreenPlus.createTextFrame(nil, panel, availableWidth - (margeH * 2), ScreenPlus.getHelpText(), 0)
	subFrame:SetPoint("TOPLEFT", infosFrame, "BOTTOMLEFT", 0, -20)
	ScreenPlus.setFontStyle(subFrame.font, nil, 12, "#CCCCCC", false, nil)
	------------------------- rappel bind
	local frameKey = ScreenPlus.createTextFrame(addonVar["settingsPanel"].."_FrameKey", panel, availableWidth - (margeH * 2), "", 15)
	frameKey:SetPoint("TOPLEFT", subFrame, "BOTTOMLEFT", 0, -20)
	ScreenPlus.setFontStyle(frameKey.font, nil, 12, nil, false, nil) -- size only : couleur définie par .showBindedKeys()
	ScreenPlus.setRoundBorderedFrame(frameKey, "595A7B", 0.5, nil)
	------------------------- cmds
	subFrame = ScreenPlus.createTextFrame(addonVar["settingsPanel"].."_Commands", panel, availableWidth - (margeH * 2), "", 15)
	subFrame:SetPoint("TOPLEFT", frameKey, "BOTTOMLEFT", 0, -20)
	ScreenPlus.setFontStyle(subFrame.font, nil, 10, "#CCCCCC", false, nil)
	ScreenPlus.setRoundBorderedFrame(subFrame, nil, nil, nil)
	------------------------- btn bas
	--if (not ScreenPlus.isRetail()) then
		local button = ScreenPlus.createStandardButton(nil, panel, ScreenPlus.getLocal("Settings"), 120)
		button:SetPoint("BOTTOM", panel, "BOTTOM", 0, 20)
		button:SetScript("OnClick", function()
			ScreenPlus.settingsPanelClose()
		end)
	--end
end

-------------------------------------------------------- FCNs (templates)


----------------------------------------------------------------------------------------
----------------------------------- UPDATE (onShow) ------------------------------------

function ScreenPlus.settingsPanelUpdate()
	local capture, cameraMode = ScreenPlus.showBindedKeys()
	_G[addonVar["settingsPanel"].."_FrameKey"]:SetText(capture.."\n"..cameraMode)
	_G[addonVar["settingsPanel"].."_Commands"]:SetText(ScreenPlus.getLocal("Available commands:").."\n\n"..ScreenPlus.slashCmd_showList(true))
end
	
function ScreenPlus.getHelpText()
	local tmp = ""
	
	tmp = tmp..ScreenPlus.getLocal("ScreenPlus is an advanced tool to take screen captures.").."\n\n"
	tmp = tmp..ScreenPlus.getLocal("Its configuration interface allows you to choose which names to display during a screen capture: players, NPCs or pets.").."\n\n"
	tmp = tmp..ScreenPlus.getLocal("Possibility to display a large or a small legend on screenshots with different options.").."\n\n"
	tmp = tmp..ScreenPlus.getLocal("In addition, ScreenPlus allows you to enter 'camera' mode by hiding the main interface, before taking a screenshot.").."\n"
	tmp = tmp..ScreenPlus.getLocal("In this mode, audio and text alerts can signal the receipt of chat messages, which allows you to be informed when the main interface is hidden.").."\n\n"
	tmp = tmp..ScreenPlus.getLocal("With a single snapshot key, ScreenPlus performs the following sequence:").."\n\n"
	tmp = tmp.."   - "..ScreenPlus.getLocal("show or hides user-defined names").."\n"
	tmp = tmp.."   - "..ScreenPlus.getLocal("displays a caption with shooting informations").."\n"
	tmp = tmp.."   - "..ScreenPlus.getLocal("takes a screen capture").."\n"
	tmp = tmp.."   - "..ScreenPlus.getLocal("restores settings and shows again the main WoW interface")
	
	return tmp
end

----------------------------------------------------------------------------------------
------------------------- GESTION SETTINGS (ne pas déplacer) ---------------------------

if (panel == nil) then
	------------------------------- création frame settings
	panel = CreateFrame("Frame", addonVar["settingsPanel"])
	local background = panel:CreateTexture()
	background:SetAllPoints(panel)
	background:SetColorTexture(0.1, 0.1, 0.1, 0.15)
	ScreenPlus.settingsCreate()
	panel:SetScript("OnShow", function(self)
		ScreenPlus.settingsPanelUpdate()
	end)
	------------------------------- enregistrement dans le panneau de settings de WoW
	if (Settings ~= nil) then -- wow10
		local category = Settings.RegisterCanvasLayoutCategory(panel, addonVar["name"])
		-- OU, pour un panneau scrolling : local category = Settings.RegisterVerticalLayoutCategory(addonVar["name"])
		Settings.RegisterAddOnCategory(category)
		panel.categoryID = category:GetID() -- pour appel depuis fichier lua principal
	else -- wow classic
		panel.name = addonVar["name"]
		-- panel.okay = function (self) ScreenPlus.settingsValidate() end -- non géré (automatique si wow10)
		-- panel.cancel = function (self) ScreenPlus.settingsCancel() end -- non géré (impossible si wow10)
		panel.default = function (self) ScreenPlus.settingsPanelDefault() end
		panel.refresh = function (self) ScreenPlus.settingsPanelUpdate() end
		InterfaceOptions_AddCategory(panel)
	end
end

function ScreenPlus.settingsPanelDefault()
	if (_G[addonVar["settingsPanel"]]:IsVisible()) then -- sinon, ca concerne pas cet addon
		ScreenPlus.reset()
	end
end

function ScreenPlus.settingsPanelClose()
	if (ScreenPlus.isRetail()) then
		-- wow10 alert-- SettingsPanel:Close() -- frame des settings des addons wow10
		HideUIPanel(SettingsPanel)
		HideUIPanel(GameMenuFrame)
	else
		InterfaceOptionsFrame:Hide() -- frame des settings des addons (non wow10)
	end 
	
	ScreenPlus.showCfgUI() -- /////
end
